Crusade: Lisbon Lisbon, Portugal November 4th 2001 Luis Duarte Deck Name: Gangrel say goodbye to the Camarilla! Type: Vote/Bloat The deck strength resides on the vampires titles. The big ones can be brought faster boosted by Ingrid's ability, Dreams of the Sphinx, Powerbase:Montreal and especially Zillah's Valley. Ramona's ability is very useful especially if she runs out of blood after playing some protean action modifiers. - Zillah's Valley is very useful to control faster big vampires and in the mid-game it makes a great combo with Parity Shift. ;) - Creepshow Casino is very useful to political actions, to hunt, ... - Powerbase:Montreal is a good way to place an additional blood on an uncontrolled vampire with nmo cost. The Second Traditions never get jammed on hand for long periods... and it can be combined with Ecoterrorists for a blood cow! - Elysium:Palace of Versailles helps adding some votes. - Visit From The Capuchin is very very good, and it has a similar effect as Dreams of the Sphynx on card advantage. - Fifth Traditions are a great blood source combined with Minion Tap for bloat. - Judgement:Camarilla Segregation are useful and most of the times other players burn vampires in torpor. - Masochisms help paying some cards costs like Earth Control and Rapid Change. It can be combined with Flesh of Marble. - Ablative Skin is a add-on, just in case, to prevent some extra damage. - Rapid Change sometimes is useful to end combat. - Closed Session helps against the Lasombra and other Sabbat votes against. - Parity Shifts help control the table. Can be combined with Zillah's Valley to meet the pool requirements during the turn it is played. - Banishments are easy to play on most vampires since the titled Gangrels are high capacity. - Corruption's Purge are playable on all Setite at once, burning 2 blood and sending them to torpor if they don't have 2 blood to burn. Useful it your predator has plenty of Followers of Set. - Protect Thine Own helps burning some weenie non-Camarilla vampires. - Flesh of Marble almost kill Potence decks, and if the damage is aggravated it can be combined with Skin of Night. The single point of damage "feeds" the Masochism. - Second Tradition are a good example how a card justifies the use of bigger titled Camarilla vampires. Wake, untap, with +2 intercept is very good on a single card. Without this card, this deck almost got no real effective defense without changing other cards and its proportions. Crypt (12 cards, min=13, max=39, avg=7.33) ------------------------------------------ 3x Angus the Unruled 10 ANI PRO cel for pot justicar Gangrel:1 3x Ingrid Rossler 9 ANI FOR PRO dom prince Gangrel:2 2x Katarina 9 ANI FOR pot pro prince Gangrel:2 2x Chandler Hungerford 3 PRO Gangrel:2 1x Ramona 4 for pro Gangrel:2 1x Ricki Van Demsi 3 for pro Gangrel:1 Library (90 cards) Master (18) 1x Backways 3x Blood Doll 1x Creepshow Casino -- Final Nights 2x Dreams of the Sphinx 1x Ecoterrorists 1x Elysium: The Palace of Versailles 4x Minion Tap 1x Powerbase: Montreal -- Sabbat War 1x Visit from the Capuchin -- Final Nights 3x Zillah's Valley -- Final Nights Action (14) 1x Ablative Skin 2x Army of Rats 5x Fifth Tradition: Hospitality 4x Judgment: Camarilla Segregation 2x Masochism Political Action (16) 1x Ancient Influence 2x Banishment 2x Conservative Agitation 2x Corruption's Purge 2x Disputed Territory 2x Dramatic Upheaval 2x Parity Shift 1x Political Stranglehold 2x Protect Thine Own Action Modifier (10) 2x Closed Session 6x Earth Control 1x Freak Drive 1x Kiss of Ra, The Action Modifier/Combat (5) 5x Rapid Change Reaction (13) 4x Cats' Guidance 9x Second Tradition: Domain Combat (14) 5x Earth Meld 7x Flesh of Marble 2x Skin of Night